import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "../components/ui/toaster";
import { TooltipProvider } from "../components/ui/tooltip";
import { useEffect, lazy, Suspense, memo } from "react";

// Removed performance monitor import for deployment
import NotFound from "./pages/not-found";
import Home from "./pages/Home";
import CRM from "./pages/CRM";
// PainterNetwork page has been removed
import Marinas from "./pages/Marinas";
import FirePrevention from "./pages/FirePrevention";
import Painters from "./pages/Painters";
import Pools from "./pages/Pools";
const Construction = lazy(() => import('./pages/Construction'));
import MobileHome from "./pages/MobileHome";
import Municipality from "./pages/Municipality";
const Applications = lazy(() => import('./pages/Applications')); 
import ProductComparison from "./pages/ProductComparison";
const Products = lazy(() => import('./pages/Products'));
const ProductsNew = lazy(() => import('./pages/ProductsNew'));

const ROICalculator = lazy(() => import('./pages/ROICalculator'));
import Technology from "./pages/Technology";
import AuthPage from "./pages/auth-page";
import ClientDashboard from "./pages/client-dashboard";
import AdminDashboard from "./pages/admin-dashboard";
const About = lazy(() => import('./pages/About'));
import Team from "./pages/Team";
import CrmLogin from "./pages/crm-login";
import CrmDashboard from "./pages/crm-dashboard";
import InventoryPage from "./pages/inventory";
import RAGDocumentsPage from "./pages/rag-documents";
import ChatPage from "./pages/chat";
import PitchDeck from "./pages/PitchDeck";
import Solar from "./pages/Solar";
import CartPage from "./pages/Cart";
import CheckoutPage from "./pages/Checkout";
const EnhancedCheckoutPage = lazy(() => import('./pages/EnhancedCheckout'));
const AnalyticsPage = lazy(() => import('./pages/Analytics'));
import Petroleum from "./pages/Petroleum";
// Case study magazine-style article pages
import WaterworldCase from "./pages/WaterworldCase";
import LGHeadquartersCase from "./pages/LGHeadquartersCase";
import IncheonBridgeCase from "./pages/IncheonBridgeCase";
import NasaDevelopmentCase from "./pages/NasaDevelopmentCase";
import NamhaeBridgeCase from "./pages/NamhaeBridgeCase";
import SeohaeBridgeCase from "./pages/SeohaeBridgeCase";
import StLouisCase from "./pages/StLouisCase";
import KoreanInfrastructureCase from "./pages/KoreanInfrastructureCase";
import ProfessionalPaintersCase from "./pages/ProfessionalPaintersCase";
// All unused pages have been removed
import { AuthProvider } from "../hooks/use-auth";
import { ProtectedRoute } from "../components/ProtectedRoute";
import { StoreProvider } from "../contexts/StoreContext";
import { ShippingProvider } from "../contexts/ShippingContext";

// Loading component for suspense boundaries
const LoadingSpinner = memo(() => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-500"></div>
  </div>
));

function Router() {
  const [location] = useLocation();

  return (
    <Switch>
      <Route path="/" component={Home} />
      <Route path="/crm" component={CRM} />
      {/* Remove painter-network route to avoid redirects */}
      <Route path="/marinas" component={Marinas} />
      <Route path="/fire-prevention" component={FirePrevention} />
      <Route path="/painters" component={Painters} />
      <Route path="/pools" component={Pools} />
      <Route path="/construction" >
        <Suspense fallback={<div>Loading...</div>}>
          <Construction />
        </Suspense>
      </Route>
      <Route path="/mobile-home" component={MobileHome} />

      <Route path="/municipality" component={Municipality} />
      <Route path="/applications">
        <Suspense fallback={<div>Loading...</div>}>
          <Applications />
        </Suspense>
      </Route>
      <Route path="/products">
        <Suspense fallback={<div>Loading...</div>}>
          <Products />
        </Suspense>
      </Route>
      <Route path="/products-new">
        <Suspense fallback={<div>Loading...</div>}>
          <ProductsNew />
        </Suspense>
      </Route>

      <Route path="/roi-calculator">
        <Suspense fallback={<div>Loading...</div>}>
          <ROICalculator />
        </Suspense>
      </Route>
      <Route path="/product-comparison" component={ProductComparison} />
      <Route path="/about">
        <Suspense fallback={<div>Loading...</div>}>
          <About />
        </Suspense>
      </Route>
      <Route path="/team" component={Team} />
      <Route path="/technology">
        <Suspense fallback={<div>Loading...</div>}>
          <Technology />
        </Suspense>
      </Route>
      <Route path="/auth" component={AuthPage} />
      <Route path="/crm-login" component={CrmLogin} />
      <Route path="/crm-dashboard" component={CrmDashboard} />
      <Route path="/inventory" component={InventoryPage} />
      <Route path="/rag-documents" component={RAGDocumentsPage} />
      <Route path="/chat" component={ChatPage} />
      <Route path="/pitch-deck" component={PitchDeck} />
      <Route path="/solar" component={Solar} />
      <Route path="/cart" component={CartPage} />
      <Route path="/checkout" component={CheckoutPage} />
      <Route path="/enhanced-checkout">
        <Suspense fallback={<div>Loading...</div>}>
          <EnhancedCheckoutPage />
        </Suspense>
      </Route>
      <Route path="/analytics">
        <Suspense fallback={<div>Loading...</div>}>
          <AnalyticsPage />
        </Suspense>
      </Route>
      <Route path="/petroleum" component={Petroleum} />
      
      {/* Case Study Magazine-Style Article Routes - Restored individually */}
      <Route path="/waterworld-case" component={WaterworldCase} />
      <Route path="/lg-headquarters-case" component={LGHeadquartersCase} />
      <Route path="/incheon-bridge-case" component={IncheonBridgeCase} />
      <Route path="/nasa-development-case" component={NasaDevelopmentCase} />
      <Route path="/namhae-bridge-case" component={NamhaeBridgeCase} />
      <Route path="/seohae-bridge-case" component={SeohaeBridgeCase} />
      <Route path="/st-louis-case" component={StLouisCase} />
      <Route path="/korean-infrastructure-case" component={KoreanInfrastructureCase} />
      <Route path="/professional-painters-case" component={ProfessionalPaintersCase} />
      
      {/* All unused case study routes have been removed */}
      <ProtectedRoute path="/client-dashboard" component={ClientDashboard} />
      <ProtectedRoute path="/admin-dashboard" component={AdminDashboard} adminOnly={true} />
      {/* Fallback to 404 */}
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  // Preload critical images once when app loads
  useEffect(() => {
    // This triggers preloading of all critical site images
    // preloadCriticalImages();

    // Remove forced dark mode to allow normal styling

    // Add performance monitoring
    if (typeof window !== 'undefined') {
      // Report largest contentful paint for performance monitoring
      const observer = new PerformanceObserver((list) => {
        const entries = list.getEntries();
        const lastEntry = entries[entries.length - 1];
        if (lastEntry && lastEntry.startTime > 0) {
          // console.log(`Largest Contentful Paint: ${lastEntry.startTime}ms`);
        }
      });

      observer.observe({ type: 'largest-contentful-paint', buffered: true });
    }
  }, []);

  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <Toaster />
        <AuthProvider>
          <StoreProvider>
            <ShippingProvider>
              <Router />
            </ShippingProvider>
          </StoreProvider>
        </AuthProvider>
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;